@@ -18,7 +18,7 @@ use vars qw(@ISA @EXPORT %dh);
 	    &inhibit_log &load_log &write_log &commit_override_log
 	    &dpkg_architecture_value &sourcepackage
 	    &is_make_jobserver_unavailable &clean_jobserver_makeflags
-	    &cross_command &set_buildflags);
+	    &cross_command &set_buildflags &get_buildoption);
 
 my $max_compat=9;
 
@@ -146,6 +146,8 @@ sub write_log {
 	my $cmd=shift;
 	my @packages=@_;
 
+	return if $dh{NO_ACT};
+
 	foreach my $package (@packages) {
 		my $log=logfile($package);
 		open(LOG, ">>", $log) || error("failed to write to ${log}: $!");
@@ -157,6 +159,8 @@ sub write_log {
 sub commit_override_log {
 	my @packages=@_;
 
+	return if $dh{NO_ACT};
+
 	foreach my $package (@packages) {
 		my @log=map { remove_override($_) } load_log($package);
 		my $log=logfile($package);
@@ -922,4 +926,21 @@ sub set_buildflags {
 	}
 }
 
+# Gets a DEB_BUILD_OPTIONS option, if set.
+sub get_buildoption {
+	my $wanted=shift;
+
+	return undef unless exists $ENV{DEB_BUILD_OPTIONS};
+
+	foreach my $opt (split(/\s+/, $ENV{DEB_BUILD_OPTIONS})) {
+		# currently parallel= is the only one with a parameter
+		if ($opt =~ /^parallel=(-?\d+)$/ && $wanted eq 'parallel') {
+			return $1;
+		}
+		elsif ($opt eq $wanted) {
+			return 1;
+		}
+	}
+}
+
 1
